@@ -23,6 +23,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/go-cmp/cmp"
 	"go.opencensus.io/resource"
 
 	"go.opencensus.io/metric/metricdata"
@@ -179,14 +180,14 @@ func Test_Worker_MultiExport(t *testing.T) {
 
 	// Format is Resource.Labels encoded as string, then
 	wantPartialData := map[string][]*Row{
-		makeKey(nil, count.Name): []*Row{
+		makeKey(nil, count.Name): {
 			{[]tag.Tag{{Key: key, Value: "a"}}, &CountData{Value: 2}},
 			{[]tag.Tag{{Key: key, Value: "b"}}, &CountData{Value: 1}},
 		},
-		makeKey(nil, sum.Name): []*Row{
+		makeKey(nil, sum.Name): {
 			{nil, &SumData{Value: 7.5}},
 		},
-		makeKey(&extraResource, count.Name): []*Row{
+		makeKey(&extraResource, count.Name): {
 			{[]tag.Tag{{Key: key, Value: "b"}}, &CountData{Value: 1}},
 		},
 	}
@@ -213,12 +214,12 @@ func Test_Worker_MultiExport(t *testing.T) {
 			case *CountData:
 				got := ts.Points[0].Value.(int64)
 				if wantValue.Value != got {
-					t.Errorf("Mismatched value (want %d, got %d) for %v in %q", wantValue, got, ts, key)
+					t.Errorf("Mismatched value (want %d, got %d) for %v in %q", wantValue.Value, got, ts, key)
 				}
 			case *SumData:
 				got := ts.Points[0].Value.(float64)
 				if wantValue.Value != got {
-					t.Errorf("Mismatched value (want %f, got %f) for %v in %q", wantValue, got, ts, key)
+					t.Errorf("Mismatched value (want %f, got %f) for %v in %q", wantValue.Value, got, ts, key)
 				}
 			default:
 				t.Errorf("Unexpected type of data: %T for %v in %q", wantValue, want[i], key)
@@ -335,20 +336,22 @@ func Test_Worker_RecordFloat64(t *testing.T) {
 
 		for _, w := range tc.wants {
 			gotRows, err := RetrieveData(w.v.Name)
+			for i := range gotRows {
+				switch data := gotRows[i].Data.(type) {
+				case *CountData:
+					data.Start = time.Time{}
+				case *SumData:
+					data.Start = time.Time{}
+				case *DistributionData:
+					data.Start = time.Time{}
+				}
+			}
 			if (err != nil) != (w.err != nil) {
 				t.Fatalf("%s: RetrieveData(%v) = %v; want error = %v", tc.label, w.v.Name, err, w.err)
 			}
-			for _, got := range gotRows {
-				if !containsRow(w.rows, got) {
-					t.Errorf("%s: got row %#v; want none", tc.label, got)
-					break
-				}
-			}
-			for _, want := range w.rows {
-				if !containsRow(gotRows, want) {
-					t.Errorf("%s: got none; want %#v'", tc.label, want)
-					break
-				}
+			if diff := cmp.Diff(gotRows, w.rows); diff != "" {
+				t.Errorf("%v: unexpected row (got-, want+): %s", tc.label, diff)
+				break
 			}
 		}
 
